pub enum BarrierType {
DownAndOut,
DownAndIn,
UpAndOut,
UpAndIn,
}Expand description
Barrier option type (single barrier, European exercise).
Variants
DownAndOut
Knocked out if spot falls to or below the barrier.
DownAndIn
Knocked in (activated) if spot falls to or below the barrier.
UpAndOut
Knocked out if spot rises to or above the barrier.
UpAndIn
Knocked in (activated) if spot rises to or above the barrier.