complex_div

Function complex_div 

pub fn complex_div(a: Complex, b: Complex) -> Result<Complex, SolMathError>
Complex division at SCALE.

Uses a scaled Smith algorithm and verifies the result by multiplying it back by the divisor. Ill-conditioned cases that cannot meet the backward error bound fail closed with NoConvergence.